@@ -61,7 +61,7 @@ impl Player {
         }
     }
 
-    async fn throw_potato(&self) {
+    fn throw_potato(&self) {
         let message = Message::IHaveThePotato(self.node().name().into());
         let message = bincode::serialize(&message).unwrap();
         self.node().send_broadcast(message.into()).unwrap();
@@ -177,7 +177,7 @@ impl Reading for Player {
                 }
 
                 self.potato_count.fetch_add(1, Relaxed);
-                self.throw_potato().await;
+                self.throw_potato();
             }
             Message::IHaveThePotato(carrier) => {
                 let mut other_players = self.other_players.lock();
@@ -199,7 +199,7 @@ impl Reading for Player {
 impl Writing for Player {
     fn write_message(&self, _: SocketAddr, payload: &[u8], buffer: &mut [u8]) -> io::Result<usize> {
         buffer[..2].copy_from_slice(&(payload.len() as u16).to_le_bytes());
-        buffer[2..][..payload.len()].copy_from_slice(&payload);
+        buffer[2..][..payload.len()].copy_from_slice(payload);
         Ok(2 + payload.len())
     }
 }
@@ -230,7 +230,7 @@ async fn main() {
 
     let first_carrier = RNG.lock().gen_range(0..NUM_PLAYERS);
     players[first_carrier].potato_count.fetch_add(1, Relaxed);
-    players[first_carrier].throw_potato().await;
+    players[first_carrier].throw_potato();
 
     sleep(Duration::from_secs(GAME_TIME_SECS)).await;
 
