@@ -21,7 +21,7 @@ impl Pea2Pea for ChattyNode {
 impl Writing for ChattyNode {
     fn write_message(&self, _: SocketAddr, payload: &[u8], buffer: &mut [u8]) -> io::Result<usize> {
         buffer[..2].copy_from_slice(&(payload.len() as u16).to_le_bytes());
-        buffer[2..][..payload.len()].copy_from_slice(&payload);
+        buffer[2..][..payload.len()].copy_from_slice(payload);
         Ok(2 + payload.len())
     }
 }
