@@ -63,7 +63,7 @@ impl Reading for TestNode {
 impl Writing for TestNode {
     fn write_message(&self, _: SocketAddr, payload: &[u8], buffer: &mut [u8]) -> io::Result<usize> {
         buffer[..2].copy_from_slice(&(payload.len() as u16).to_le_bytes());
-        buffer[2..][..payload.len()].copy_from_slice(&payload);
+        buffer[2..][..payload.len()].copy_from_slice(payload);
         Ok(2 + payload.len())
     }
 }
@@ -155,9 +155,9 @@ async fn check_node_cleanups() {
     // peak heap use: 354.17kB; total heap growth: 1.0308341
     let alloc_growth = max_heap_use / peak_heap_post_1st_conn;
     println!(
-        "peak heap use: {:.2}kB; total heap growth after {} connections: {}",
+        "peak heap use: {:.2}kB; total heap growth after {} connections: {:.2}",
         max_heap_use, NUM_CONNECTIONS, alloc_growth
     );
 
-    assert!(alloc_growth < 1.05);
+    assert!(alloc_growth < 1.1);
 }
